##  Definition
Business contexts describe the specific activities an organization performs to achieve its business goals. They can be clustered and analyzed by things such as products, processes, customer journeys, and value streams.
